# Telliot Feed Examples

This package contains reporting tools and datafeeds for the TellorX and TellorFlex oracles.

## [Project documentation](https://tellor-io.github.io/telliot-feed-examples/)

## [Installation and Configuration](https://tellor-io.github.io/telliot-feed-examples/getting-started/)

## [Usage](https://tellor-io.github.io/telliot-feed-examples/usage/)

## Example

Report using the CLI:
```
telliot-examples -a fakeaccountname report
```
